==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/PrintSettings.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "documentConversionEnabled"})
@JsonInclude(Include.NON_NULL)
public class PrintSettings implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("documentConversionEnabled")
    protected Boolean documentConversionEnabled;

    protected PrintSettings() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.printSettings";
    }

    @Property(name="documentConversionEnabled")
    @JsonIgnore
    public Optional<Boolean> getDocumentConversionEnabled() {
        return Optional.ofNullable(documentConversionEnabled);
    }

    public PrintSettings withDocumentConversionEnabled(Boolean documentConversionEnabled) {
        PrintSettings _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.printSettings");
        _x.documentConversionEnabled = documentConversionEnabled;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private Boolean documentConversionEnabled;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder documentConversionEnabled(Boolean documentConversionEnabled) {
            this.documentConversionEnabled = documentConversionEnabled;
            this.changedFields = changedFields.add("documentConversionEnabled");
            return this;
        }

        public PrintSettings build() {
            PrintSettings _x = new PrintSettings();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.printSettings";
            _x.documentConversionEnabled = documentConversionEnabled;
            return _x;
        }
    }

    private PrintSettings _copy() {
        PrintSettings _x = new PrintSettings();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.documentConversionEnabled = documentConversionEnabled;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("PrintSettings[");
        b.append("documentConversionEnabled=");
        b.append(this.documentConversionEnabled);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/PrintSettings.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Boolean;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "documentConversionEnabled"})
@JsonInclude(Include.NON_NULL)
public class PrintSettings implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("documentConversionEnabled")
    protected Boolean documentConversionEnabled;

    protected PrintSettings() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.printSettings";
    }

    @Property(name="documentConversionEnabled")
    @JsonIgnore
    public Optional<Boolean> getDocumentConversionEnabled() {
        return Optional.ofNullable(documentConversionEnabled);
    }

    public PrintSettings withDocumentConversionEnabled(Boolean documentConversionEnabled) {
        PrintSettings _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.printSettings");
        _x.documentConversionEnabled = documentConversionEnabled;
        return _x;
    }

    public PrintSettings withUnmappedField(String name, Object value) {
        PrintSettings _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private Boolean documentConversionEnabled;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder documentConversionEnabled(Boolean documentConversionEnabled) {
            this.documentConversionEnabled = documentConversionEnabled;
            this.changedFields = changedFields.add("documentConversionEnabled");
            return this;
        }

        public PrintSettings build() {
            PrintSettings _x = new PrintSettings();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.printSettings";
            _x.documentConversionEnabled = documentConversionEnabled;
            return _x;
        }
    }

    private PrintSettings _copy() {
        PrintSettings _x = new PrintSettings();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.documentConversionEnabled = documentConversionEnabled;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("PrintSettings[");
        b.append("documentConversionEnabled=");
        b.append(this.documentConversionEnabled);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
